#include "include/tools/python_execute.h"
#include "mcp/include/mcp_client.h"
#include "mcp/include/mcp_tool.h"
#include <iostream>

namespace openmanus {

PythonExecute::PythonExecute()
    : ToolBase("PythonExecute", "执行Python代码并返回结果") {
    // 使用tool_builder构建工具定义
    mcp::tool_builder builder("PythonExecute");
    builder.with_description("执行Python代码并返回结果");
    builder.with_string_param("code", "要执行的Python代码", true);
    mcp::tool tool = builder.build();
    
    // 从构建的工具中获取参数定义
    parameters_ = tool.parameters_schema;
}

mcp::json PythonExecute::execute(const mcp::json& params) {
    if (!params.contains("code")) {
        throw std::runtime_error("缺少'code'参数");
    }
    
    std::string code = params["code"];
    
    try {
        // 创建MCP客户端
        mcp::client client("localhost", 8080);
        
        // 初始化客户端
        client.initialize("OpenManusCppClient", "0.1.0");
        
        // 调用PythonExecute工具
        mcp::json tool_params = {{"code", code}};
        mcp::json result = client.call_tool("PythonExecute", tool_params);
        
        return result;
    } catch (const std::exception& e) {
        std::cerr << "执行Python代码失败: " << e.what() << std::endl;
        mcp::json error_result;
        error_result["success"] = false;
        error_result["error"] = e.what();
        return error_result;
    }
}

} // namespace openmanus 